Learn R Programming

RBM (version 1.4.0)

RBM_T: RBM_T: a R function for microarray and RNA-Seq data analysis for two-group comparisons

Description

Use A Resampling-Based Empirical Bayes Approach to Assess Differential Expression or Identify differntially methylated loci in Two-Color Microarrays and RNA-Seq data sets.

Usage

RBM_T(aData, vec_trt, repetition, alpha)

Arguments

aData
The input data set with rows and columns denoting features and samples, respectively
vec_trt
A vector for group notation such as 1s denote treatment group and 0s denote control group
repetition
The number of resamplings used in the analysis. You could use 1000 or higher number
alpha
The signifiance level

Value

RBM_T produces a named list with the following components:
ordfit_t
orignal t statistics
ordfit_pvalue
original p-values from lmFit and eBayes
ordfit_beta0
estimated mean for the control group
ordfit_beta1
estimated mean difference between treatment and control group
permutation_p
calculated p-values from permutation method based on resampled test statistics
bootstrap_p
calculated p-values from bootstrap method based on resampled test statistics

Details

Combine resampling with empirical Bayes approach for Microarrays and RNA-Seq data analysis.

References

Li D, Le Pape MA, Parikh NI, Chen WX, Dye TD (2013) Assessing Differential Expression in Two-Color Microarrays: A Resampling-Based Empirical Bayes Approach. PLoS ONE 8(11): e80099. doi: 10.1371/journal.pone.0080099

See Also

The RBM_F function defined in this package. The limma and marray packages.

Examples

Run this code
normal_data <- matrix(rnorm(200*6), 200, 6)
mydesign <- c(0,0,0,1,1,1)
norm_result <- RBM_T(normal_data,mydesign,50,0.05)
    
unif_data <- matrix(runif(200*7, 0.10, 0.95), 200, 7)
mydesign2 <- c(0,0,0, 1,1,1,1)
unif_result <- RBM_T(unif_data,mydesign2,100,0.05)

Run the code above in your browser using DataLab